@@ -24,10 +24,7 @@
 #ifndef __ALBUMART_H__
 #define __ALBUMART_H__
 
-void
-update_if_album_art(const char *path);
-
-int64_t
-find_album_art(const char *path, const char *image_data, int image_size);
+void update_if_album_art(const char *path);
+int64_t find_album_art(const char *path, uint8_t *image_data, int image_size);
 
 #endif
