@@ -24,6 +24,7 @@
 #ifndef __SQL_H__
 #define __SQL_H__
 
+#include <stdint.h>
 #include <sqlite3.h>
 
 #ifndef HAVE_SQLITE3_MALLOC
@@ -33,19 +34,11 @@
 #define sqlite3_prepare_v2 sqlite3_prepare
 #endif
 
-int
-sql_exec(sqlite3 *db, const char *fmt, ...);
-
-int
-sql_get_table(sqlite3 *db, const char *zSql, char ***pazResult, int *pnRow, int *pnColumn);
-
-int
-sql_get_int_field(sqlite3 *db, const char *fmt, ...);
-
-char *
-sql_get_text_field(sqlite3 *db, const char *fmt, ...);
-
-int
-db_upgrade(sqlite3 *db);
+int sql_exec(sqlite3 *db, const char *fmt, ...);
+int sql_get_table(sqlite3 *db, const char *zSql, char ***pazResult, int *pnRow, int *pnColumn);
+int sql_get_int_field(sqlite3 *db, const char *fmt, ...);
+int64_t sql_get_int64_field(sqlite3 *db, const char *fmt, ...);
+char * sql_get_text_field(sqlite3 *db, const char *fmt, ...);
+int db_upgrade(sqlite3 *db);
 
 #endif
